@@ -1,10 +1,9 @@
-// SPDX-FileCopyrightText: none
-// SPDX-License-Identifier: GPL-3.0-only
+// SPDX-FileCopyrightText: 2022 Plata Hill <plata.hill@kdemail.net>
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "groupfactory.h"
 
 #include "database.h"
-#include "fetcher.h"
 #include "group.h"
 
 #include <QDebug>
@@ -25,11 +24,15 @@ Group *GroupFactory::create(int index) const
     // try to load if not avaible
     if (m_groups.size() <= index) {
         load();
+
+        // check if requested data exists
+        // load() changes m_groups
+        // cppcheck-suppress identicalInnerCondition
+        if (m_groups.size() <= index) {
+            return nullptr;
+        }
     }
-    // check if requested data exists
-    if (m_groups.size() <= index) {
-        return nullptr;
-    }
+
     return new Group(m_groups.at(index));
 }
 
